Class: DropboxClient
- Inherits:
-
Object
- Object
- DropboxClient
- Defined in:
- lib/dropbox_sdk.rb
Overview
Use this class to make Dropbox API calls. You’ll need to obtain an OAuth 2 access token first; you can get one using either DropboxOAuth2Flow or DropboxOAuth2FlowNoRedirect.
Defined Under Namespace
Classes: ChunkedUploader
Constant Summary collapse
- RESERVED_CHARACTERS =
From the oauth spec plus “/”. Slash should not be ecsaped
/[^a-zA-Z0-9\-\.\_\~\/]/
Instance Method Summary collapse
-
#account_info ⇒ Object
Returns some information about the current user’s Dropbox account (the “current user” is the user associated with the access token you’re using).
-
#add_copy_ref(to_path, copy_ref) ⇒ Object
Adds the file referenced by the copy ref to the specified path.
-
#commit_chunked_upload(to_path, upload_id, overwrite = false, parent_rev = nil) ⇒ Object
:nodoc.
-
#create_copy_ref(path) ⇒ Object
Creates and returns a copy ref for a specific file.
-
#create_oauth2_access_token ⇒ Object
If this
DropboxClientwas created with an OAuth 1 access token, this method can be used to create an equivalent OAuth 2 access token. -
#delta(cursor = nil, path_prefix = nil) ⇒ Object
A way of letting you keep a local representation of the Dropbox folder heirarchy.
-
#disable_access_token ⇒ Object
Disables the access token that this
DropboxClientis using. -
#file_copy(from_path, to_path) ⇒ Object
Copy a file or folder to a new location.
-
#file_create_folder(path) ⇒ Object
Create a folder.
-
#file_delete(path) ⇒ Object
Deletes a file.
-
#file_move(from_path, to_path) ⇒ Object
Moves a file.
-
#format_path(path, escape = true) ⇒ Object
:nodoc:.
-
#get_chunked_uploader(file_obj, total_size) ⇒ Object
Returns a ChunkedUploader object.
-
#get_file(from_path, rev = nil) ⇒ Object
Download a file.
-
#get_file_and_metadata(from_path, rev = nil) ⇒ Object
Download a file and get its metadata.
-
#initialize(oauth2_access_token, root = "auto", locale = nil) ⇒ DropboxClient
constructor
Args: *
oauth2_access_token: Obtained via DropboxOAuth2Flow or DropboxOAuth2FlowNoRedirect. -
#media(path) ⇒ Object
Returns a direct link to a media file All of Dropbox’s API methods require OAuth, which may cause problems in situations where an application expects to be able to hit a URL multiple times (for example, a media player seeking around a video file).
-
#metadata(path, file_limit = 25000, list = true, hash = nil, rev = nil, include_deleted = false) ⇒ Object
Retrives metadata for a file or folder.
-
#partial_chunked_upload(data, upload_id = nil, offset = nil) ⇒ Object
:nodoc.
-
#put_file(to_path, file_obj, overwrite = false, parent_rev = nil) ⇒ Object
Uploads a file to a server.
-
#restore(path, rev) ⇒ Object
Restore a file to a previous revision.
-
#revisions(path, rev_limit = 1000) ⇒ Object
Retrive revisions of a file.
-
#search(path, query, file_limit = 1000, include_deleted = false) ⇒ Object
Search directory for filenames matching query.
-
#shares(path) ⇒ Object
Get a URL to share a media file Shareable links created on Dropbox are time-limited, but don’t require any authentication, so they can be given out freely.
-
#thumbnail(from_path, size = 'large') ⇒ Object
Download a thumbnail for an image.
-
#thumbnail_and_metadata(from_path, size = 'large') ⇒ Object
Download a thumbnail for an image along with the image’s metadata.
Constructor Details
#initialize(oauth2_access_token, root = "auto", locale = nil) ⇒ DropboxClient
Args:
-
oauth2_access_token: Obtained via DropboxOAuth2Flow or DropboxOAuth2FlowNoRedirect. -
locale: The user’s current locale (used to localize error messages).
722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/dropbox_sdk.rb', line 722 def initialize(oauth2_access_token, root="auto", locale=nil) if oauth2_access_token.is_a?(String) @session = DropboxOAuth2Session.new(oauth2_access_token, locale) elsif oauth2_access_token.is_a?(DropboxSession) @session = oauth2_access_token @session.get_access_token if not locale.nil? @session.locale = locale end else raise ArgumentError.new("oauth2_access_token doesn't have a valid type") end @root = root.to_s # If they passed in a symbol, make it a string if not ["dropbox","app_folder","auto"].include?(@root) raise ArgumentError.new("root must be :dropbox, :app_folder, or :auto") end if @root == "app_folder" #App Folder is the name of the access type, but for historical reasons #sandbox is the URL root component that indicates this @root = "sandbox" end end |
Instance Method Details
#account_info ⇒ Object
Returns some information about the current user’s Dropbox account (the “current user” is the user associated with the access token you’re using).
For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#account-info
752 753 754 755 |
# File 'lib/dropbox_sdk.rb', line 752 def account_info() response = @session.do_get "/account/info" Dropbox::parse_response(response) end |
#add_copy_ref(to_path, copy_ref) ⇒ Object
Adds the file referenced by the copy ref to the specified path
Args:
-
copy_ref: A copy ref string that was returned from a create_copy_ref call. The copy_ref can be created from any other Dropbox account, or from the same account. -
to_path: The path to where the file will be created.
Returns:
-
A hash with the metadata of the new file.
1363 1364 1365 1366 1367 1368 1369 1370 |
# File 'lib/dropbox_sdk.rb', line 1363 def add_copy_ref(to_path, copy_ref) params = {'from_copy_ref' => copy_ref, 'to_path' => "#{to_path}", 'root' => @root} response = @session.do_post "/fileops/copy", params Dropbox::parse_response(response) end |
#commit_chunked_upload(to_path, upload_id, overwrite = false, parent_rev = nil) ⇒ Object
:nodoc
916 917 918 919 920 921 922 923 924 925 |
# File 'lib/dropbox_sdk.rb', line 916 def commit_chunked_upload(to_path, upload_id, overwrite=false, parent_rev=nil) #:nodoc path = "/commit_chunked_upload/#{@root}#{format_path(to_path)}" params = {'overwrite' => overwrite.to_s, 'upload_id' => upload_id, 'parent_rev' => parent_rev, } headers = nil content_server = true @session.do_post path, params, headers, content_server end |
#create_copy_ref(path) ⇒ Object
Creates and returns a copy ref for a specific file. The copy ref can be used to instantly copy that file to the Dropbox of another account.
Args:
-
path: The path to the file for a copy ref to be created on.
Returns:
-
A Hash object that looks like the following example:
{"expires"=>"Fri, 31 Jan 2042 21:01:05 +0000", "copy_ref"=>"z1X6ATl6aWtzOGq0c3g5Ng"}
1348 1349 1350 1351 1352 |
# File 'lib/dropbox_sdk.rb', line 1348 def create_copy_ref(path) path = "/copy_ref/#{@root}#{format_path(path)}" response = @session.do_get path Dropbox::parse_response(response) end |
#create_oauth2_access_token ⇒ Object
If this DropboxClient was created with an OAuth 1 access token, this method can be used to create an equivalent OAuth 2 access token. This can be used to upgrade your app’s existing access tokens from OAuth 1 to OAuth 2.
767 768 769 770 771 772 773 774 |
# File 'lib/dropbox_sdk.rb', line 767 def create_oauth2_access_token if not @session.is_a?(DropboxSession) raise ArgumentError.new("This call requires a DropboxClient that is configured with " \ "an OAuth 1 access token.") end response = @session.do_post "/oauth2/token_from_oauth1" Dropbox::parse_response(response)['access_token'] end |
#delta(cursor = nil, path_prefix = nil) ⇒ Object
A way of letting you keep a local representation of the Dropbox folder heirarchy. You can periodically call delta() to get a list of “delta entries”, which are instructions on how to update your local state to match the server’s state.
Arguments:
-
cursor: On the first call, omit this argument (or pass innil). On subsequent calls, pass in thecursorstring returned by the previous call. -
path_prefix: If provided, results will be limited to files and folders whose paths are equal to or underpath_prefix. Thepath_prefixis fixed for a given cursor. Whateverpath_prefixyou use on the first delta() must also be passed in on subsequent calls that use the returned cursor.
Returns: A hash with three fields.
-
entries: A list of “delta entries” (described below) -
reset: Iftrue, you should reset local state to be an empty folder before processing the list of delta entries. This is onlytrueonly in rare situations. -
cursor: A string that is used to keep track of your current state. On the next call to delta(), pass in this value to return entries that were recorded since the cursor was returned. -
has_more: Iftrue, then there are more entries available; you can call delta() again immediately to retrieve those entries. Iffalse, then wait at least 5 minutes (preferably longer) before checking again.
Delta Entries: Each entry is a 2-item list of one of following forms:
-
[path, metadata]: Indicates that there is a file/folder at the given path. You should add the entry to your local state. (The metadata value is the same as what would be returned by the #metadata() call.)
-
If the path refers to parent folders that don’t yet exist in your local state, create those parent folders in your local state. You will eventually get entries for those parent folders.
-
If the new entry is a file, replace whatever your local state has at path with the new entry.
-
If the new entry is a folder, check what your local state has at path. If it’s a file, replace it with the new entry. If it’s a folder, apply the new metadata to the folder, but do not modify the folder’s children.
-
-
[path,
nil]: Indicates that there is no file/folder at the path on Dropbox. To update your local state to match, delete whatever is at path, including any children (you will sometimes also get separate delta entries for each child, but this is not guaranteed). If your local state doesn’t have anything at path, ignore this entry.
Remember: Dropbox treats file names in a case-insensitive but case-preserving way. To facilitate this, the path strings above are lower-cased versions of the actual path. The metadata dicts have the original, case-preserved path.
1308 1309 1310 1311 1312 1313 1314 1315 1316 |
# File 'lib/dropbox_sdk.rb', line 1308 def delta(cursor=nil, path_prefix=nil) params = { 'cursor' => cursor, 'path_prefix' => path_prefix, } response = @session.do_post "/delta", params Dropbox::parse_response(response) end |
#disable_access_token ⇒ Object
Disables the access token that this DropboxClient is using. If this call succeeds, further API calls using this object will fail.
759 760 761 762 |
# File 'lib/dropbox_sdk.rb', line 759 def disable_access_token @session.do_post "/disable_access_token" nil end |
#file_copy(from_path, to_path) ⇒ Object
Copy a file or folder to a new location.
Args:
-
from_path: The path to the file or folder to be copied. -
to_path: The destination path of the file or folder to be copied. This parameter should include the destination filename (e.g. from_path: ‘/test.txt’, to_path: ‘/dir/test.txt’). If there’s already a file at the to_path, this copy will be renamed to be unique.
Returns:
-
A hash with the metadata of the new copy of the file or folder. For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#fileops-copy
1018 1019 1020 1021 1022 1023 1024 1025 1026 |
# File 'lib/dropbox_sdk.rb', line 1018 def file_copy(from_path, to_path) params = { "root" => @root, "from_path" => format_path(from_path, false), "to_path" => format_path(to_path, false), } response = @session.do_post "/fileops/copy", params Dropbox::parse_response(response) end |
#file_create_folder(path) ⇒ Object
Create a folder.
Arguments:
-
path: The path of the new folder.
Returns:
-
A hash with the metadata of the newly created folder. For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#fileops-create-folder
1037 1038 1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/dropbox_sdk.rb', line 1037 def file_create_folder(path) params = { "root" => @root, "path" => format_path(path, false), } response = @session.do_post "/fileops/create_folder", params Dropbox::parse_response(response) end |
#file_delete(path) ⇒ Object
Deletes a file
Arguments:
-
path: The path of the file to delete
Returns:
-
A Hash with the metadata of file just deleted. For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#fileops-delete
1056 1057 1058 1059 1060 1061 1062 1063 |
# File 'lib/dropbox_sdk.rb', line 1056 def file_delete(path) params = { "root" => @root, "path" => format_path(path, false), } response = @session.do_post "/fileops/delete", params Dropbox::parse_response(response) end |
#file_move(from_path, to_path) ⇒ Object
Moves a file
Arguments:
-
from_path: The path of the file to be moved -
to_path: The destination path of the file or folder to be moved If the file or folder already exists, it will be renamed to be unique.
Returns:
-
A Hash with the metadata of file or folder just moved. For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#fileops-delete
1076 1077 1078 1079 1080 1081 1082 1083 1084 |
# File 'lib/dropbox_sdk.rb', line 1076 def file_move(from_path, to_path) params = { "root" => @root, "from_path" => format_path(from_path, false), "to_path" => format_path(to_path, false), } response = @session.do_post "/fileops/move", params Dropbox::parse_response(response) end |
#format_path(path, escape = true) ⇒ Object
:nodoc:
1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 |
# File 'lib/dropbox_sdk.rb', line 1375 def format_path(path, escape=true) # :nodoc: path = path.gsub(/\/+/,"/") # replace multiple slashes with a single one path = path.gsub(/^\/?/,"/") # ensure the path starts with a slash path.gsub(/\/?$/,"") # ensure the path doesn't end with a slash return URI.escape(path, RESERVED_CHARACTERS) if escape path end |
#get_chunked_uploader(file_obj, total_size) ⇒ Object
Returns a ChunkedUploader object.
Args:
-
file_obj: The file-like object to be uploaded. Must support .read() -
total_size: The total size of file_obj
828 829 830 |
# File 'lib/dropbox_sdk.rb', line 828 def get_chunked_uploader(file_obj, total_size) ChunkedUploader.new(self, file_obj, total_size) end |
#get_file(from_path, rev = nil) ⇒ Object
Download a file
Args:
-
from_path: The path to the file to be downloaded -
rev: A previous revision value of the file to be downloaded
Returns:
-
The file contents.
945 946 947 948 |
# File 'lib/dropbox_sdk.rb', line 945 def get_file(from_path, rev=nil) response = get_file_impl(from_path, rev) Dropbox::parse_response(response, raw=true) end |
#get_file_and_metadata(from_path, rev = nil) ⇒ Object
Download a file and get its metadata.
Args:
-
from_path: The path to the file to be downloaded -
rev: A previous revision value of the file to be downloaded
Returns:
-
The file contents.
-
The file metadata as a hash.
959 960 961 962 963 964 |
# File 'lib/dropbox_sdk.rb', line 959 def (from_path, rev=nil) response = get_file_impl(from_path, rev) parsed_response = Dropbox::parse_response(response, raw=true) = (response) return parsed_response, end |
#media(path) ⇒ Object
Returns a direct link to a media file All of Dropbox’s API methods require OAuth, which may cause problems in situations where an application expects to be able to hit a URL multiple times (for example, a media player seeking around a video file). This method creates a time-limited URL that can be accessed without any authentication.
Arguments:
-
path: The file to stream.
Returns:
-
A Hash object that looks like the following:
{'url': 'https://dl.dropboxusercontent.com/1/view/abcdefghijk/example', 'expires': 'Thu, 16 Sep 2011 01:01:25 +0000'}
1203 1204 1205 1206 |
# File 'lib/dropbox_sdk.rb', line 1203 def media(path) response = @session.do_get "/media/#{@root}#{format_path(path)}" Dropbox::parse_response(response) end |
#metadata(path, file_limit = 25000, list = true, hash = nil, rev = nil, include_deleted = false) ⇒ Object
Retrives metadata for a file or folder
Arguments:
-
path: The path to the file or folder.
-
list: Whether to list all contained files (only applies when path refers to a folder).
-
file_limit: The maximum number of file entries to return within a folder. If the number of files in the directory exceeds this limit, an exception is raised. The server will return at max 25,000 files within a folder.
-
hash: Every directory listing has a hash parameter attached that can then be passed back into this function later to save on bandwidth. Rather than returning an unchanged folder’s contents, if the hash matches a DropboxNotModified exception is raised.
-
rev: Optional. The revision of the file to retrieve the metadata for. This parameter only applies for files. If omitted, you’ll receive the most recent revision metadata.
-
include_deleted: Specifies whether to include deleted files in metadata results.
Returns:
-
A Hash object with the metadata of the file or folder (and contained files if appropriate). For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#metadata
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/dropbox_sdk.rb', line 1109 def (path, file_limit=25000, list=true, hash=nil, rev=nil, include_deleted=false) params = { "file_limit" => file_limit.to_s, "list" => list.to_s, "include_deleted" => include_deleted.to_s, "hash" => hash, "rev" => rev, } response = @session.do_get "/metadata/#{@root}#{format_path(path)}", params if response.kind_of? Net::HTTPRedirection raise DropboxNotModified.new("metadata not modified") end Dropbox::parse_response(response) end |
#partial_chunked_upload(data, upload_id = nil, offset = nil) ⇒ Object
:nodoc
927 928 929 930 931 932 933 934 935 |
# File 'lib/dropbox_sdk.rb', line 927 def partial_chunked_upload(data, upload_id=nil, offset=nil) #:nodoc params = { 'upload_id' => upload_id, 'offset' => offset, } headers = {'Content-Type' => "application/octet-stream"} content_server = true @session.do_put '/chunked_upload', params, headers, data, content_server end |
#put_file(to_path, file_obj, overwrite = false, parent_rev = nil) ⇒ Object
Uploads a file to a server. This uses the HTTP PUT upload method for simplicity
Args:
-
to_path: The directory path to upload the file to. If the destination directory does not yet exist, it will be created. -
file_obj: A file-like object to upload. If you would like, you can pass a string as file_obj. -
overwrite: Whether to overwrite an existing file at the given path. [default is False] If overwrite is False and a file already exists there, Dropbox will rename the upload to make sure it doesn’t overwrite anything. You must check the returned metadata to know what this new name is. This field should only be True if your intent is to potentially clobber changes to a file that you don’t know about. -
parent_rev: The rev field from the ‘parent’ of this upload. [optional] If your intent is to update the file at the given path, you should pass the parent_rev parameter set to the rev value from the most recent metadata you have of the existing file at that path. If the server has a more recent version of the file at the specified path, it will automatically rename your uploaded file, spinning off a conflict. Using this parameter effectively causes the overwrite parameter to be ignored. The file will always be overwritten if you send the most-recent parent_rev, and it will never be overwritten you send a less-recent one.
Returns:
-
a Hash containing the metadata of the newly uploaded file. The file may have a different name if it conflicted.
Simple Example
client = DropboxClient(oauth2_access_token)
#session is a DropboxSession I've already authorized
client.put_file('/test_file_on_dropbox', open('/tmp/test_file'))
This will upload the “/tmp/test_file” from my computer into the root of my App’s app folder and call it “test_file_on_dropbox”. The file will not overwrite any pre-existing file.
809 810 811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/dropbox_sdk.rb', line 809 def put_file(to_path, file_obj, overwrite=false, parent_rev=nil) path = "/files_put/#{@root}#{format_path(to_path)}" params = { 'overwrite' => overwrite.to_s, 'parent_rev' => parent_rev, } headers = {"Content-Type" => "application/octet-stream"} content_server = true response = @session.do_put path, params, headers, file_obj, content_server Dropbox::parse_response(response) end |
#restore(path, rev) ⇒ Object
Restore a file to a previous revision.
Arguments:
-
path: The file to restore. Note that folders can’t be restored.
-
rev: A previous rev value of the file to be restored to.
Returns:
-
A Hash object with a list the metadata of the file or folders restored For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#search
1182 1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/dropbox_sdk.rb', line 1182 def restore(path, rev) params = { 'rev' => rev.to_s } response = @session.do_post "/restore/#{@root}#{format_path(path)}", params Dropbox::parse_response(response) end |
#revisions(path, rev_limit = 1000) ⇒ Object
Retrive revisions of a file
Arguments:
-
path: The file to fetch revisions for. Note that revisions are not available for folders.
-
rev_limit: The maximum number of file entries to return within a folder. The server will return at max 1,000 revisions.
Returns:
-
A Hash object with a list of the metadata of the all the revisions of all matches files (up to rev_limit entries) For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#revisions
1163 1164 1165 1166 1167 1168 1169 1170 |
# File 'lib/dropbox_sdk.rb', line 1163 def revisions(path, rev_limit=1000) params = { 'rev_limit' => rev_limit.to_s } response = @session.do_get "/revisions/#{@root}#{format_path(path)}", params Dropbox::parse_response(response) end |
#search(path, query, file_limit = 1000, include_deleted = false) ⇒ Object
Search directory for filenames matching query
Arguments:
-
path: The directory to search within
-
query: The query to search on (3 character minimum)
-
file_limit: The maximum number of file entries to return/ If the number of files exceeds this limit, an exception is raised. The server will return at max 1,000
-
include_deleted: Whether to include deleted files in search results
Returns:
-
A Hash object with a list the metadata of the file or folders matching query inside path. For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#search
1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 |
# File 'lib/dropbox_sdk.rb', line 1139 def search(path, query, file_limit=1000, include_deleted=false) params = { 'query' => query, 'file_limit' => file_limit.to_s, 'include_deleted' => include_deleted.to_s } response = @session.do_get "/search/#{@root}#{format_path(path)}", params Dropbox::parse_response(response) end |
#shares(path) ⇒ Object
Get a URL to share a media file Shareable links created on Dropbox are time-limited, but don’t require any authentication, so they can be given out freely. The time limit should allow at least a day of shareability, though users have the ability to disable a link from their account if they like.
Arguments:
-
path: The file to share.
Returns:
-
A Hash object that looks like the following example:
{'url': 'https://db.tt/c0mFuu1Y', 'expires': 'Tue, 01 Jan 2030 00:00:00 +0000'}For a detailed description of what this call returns, visit:
https://www.dropbox.com/developers/reference/api#shares
1222 1223 1224 1225 |
# File 'lib/dropbox_sdk.rb', line 1222 def shares(path) response = @session.do_get "/shares/#{@root}#{format_path(path)}" Dropbox::parse_response(response) end |
#thumbnail(from_path, size = 'large') ⇒ Object
Download a thumbnail for an image.
Arguments:
-
from_path: The path to the file to be thumbnailed.
-
size: A string describing the desired thumbnail size. At this time, ‘small’ (32x32), ‘medium’ (64x64), ‘large’ (128x128), ‘s’ (64x64), ‘m’ (128x128), ‘l’ (640x640), and ‘xl’ (1024x1024) are officially supported sizes. Check www.dropbox.com/developers/reference/api#thumbnails for more details. [defaults to large]
Returns:
-
The thumbnail data
1238 1239 1240 1241 |
# File 'lib/dropbox_sdk.rb', line 1238 def thumbnail(from_path, size='large') response = thumbnail_impl(from_path, size) Dropbox::parse_response(response, raw=true) end |
#thumbnail_and_metadata(from_path, size = 'large') ⇒ Object
Download a thumbnail for an image along with the image’s metadata.
Arguments:
-
from_path: The path to the file to be thumbnailed.
-
size: A string describing the desired thumbnail size. See thumbnail() for details.
Returns:
-
The thumbnail data
-
The metadata for the image as a hash
1252 1253 1254 1255 1256 1257 |
# File 'lib/dropbox_sdk.rb', line 1252 def (from_path, size='large') response = thumbnail_impl(from_path, size) parsed_response = Dropbox::parse_response(response, raw=true) = (response) return parsed_response, end |