Class: DropboxClient

Inherits:
Object
  • Object
show all
Defined in:
lib/dropbox_sdk.rb

Overview

This is the Dropbox Client API you’ll be working with most often. You need to give it a DropboxSession which has already been authorized, or which it can authorize.

Constant Summary collapse

RESERVED_CHARACTERS =

From the oauth spec plus “/”. Slash should not be ecsaped

/[^a-zA-Z0-9\-\.\_\~\/]/

Instance Method Summary collapse

Constructor Details

#initialize(session, root = "app_folder", locale = nil) ⇒ DropboxClient

Initialize a new DropboxClient. You need to give it a session which has been authorized. See documentation on DropboxSession for how to authorize it.



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/dropbox_sdk.rb', line 298

def initialize(session, root="app_folder", locale=nil)
    session.get_access_token

    @root = root.to_s  # If they passed in a symbol, make it a string

    if not ["dropbox","app_folder"].include?(@root)
        raise DropboxError.new("root must be :dropbox or :app_folder")
    end
    if @root == "app_folder"
        #App Folder is the name of the access type, but for historical reasons
        #sandbox is the URL root component that indicates this
        @root = "sandbox"
    end

    @locale = locale
    @session = session
end

Instance Method Details

#account_infoObject

Returns account info in a Hash object

For a detailed description of what this call returns, visit: www.dropbox.com/developers/reference/api#account-info



351
352
353
354
# File 'lib/dropbox_sdk.rb', line 351

def ()
    response = @session.do_get build_url("/account/info")
    parse_response(response)
end

#add_copy_ref(to_path, copy_ref) ⇒ Object

Adds the file referenced by the copy ref to the specified path

Args:

  • copy_ref: A copy ref string that was returned from a create_copy_ref call. The copy_ref can be created from any other Dropbox account, or from the same account.

  • to_path: The path to where the file will be created.

Returns:

  • A hash with the metadata of the new file.



832
833
834
835
836
837
838
839
840
841
842
# File 'lib/dropbox_sdk.rb', line 832

def add_copy_ref(to_path, copy_ref)
    path = "/fileops/copy"

    params = {'from_copy_ref' => copy_ref,
              'to_path' => "#{format_path(to_path)}",
              'root' => @root}

    response = @session.do_post(build_url(path, params))

    parse_response(response)
end

#build_url(url, params = nil, content_server = false) ⇒ Object

:nodoc:



844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
# File 'lib/dropbox_sdk.rb', line 844

def build_url(url, params=nil, content_server=false) # :nodoc:
    port = 443
    host = content_server ? Dropbox::API_CONTENT_SERVER : Dropbox::API_SERVER
    versioned_url = "/#{Dropbox::API_VERSION}#{url}"

    target = URI::Generic.new("https", nil, host, port, nil, versioned_url, nil, nil, nil)

    #add a locale param if we have one
    #initialize a params object is we don't have one
    if @locale
        (params ||= {})['locale']=@locale
    end

    if params
        target.query = params.collect {|k,v|
            URI.escape(k) + "=" + URI.escape(v)
        }.join("&")
    end

    target.to_s
end

#create_copy_ref(path) ⇒ Object

Creates and returns a copy ref for a specific file. The copy ref can be used to instantly copy that file to the Dropbox of another account.

Args:

  • path: The path to the file for a copy ref to be created on.

Returns:

  • A Hash object that looks like the following example:

    {"expires"=>"Fri, 31 Jan 2042 21:01:05 +0000", "copy_ref"=>"z1X6ATl6aWtzOGq0c3g5Ng"}
    


815
816
817
818
819
820
821
# File 'lib/dropbox_sdk.rb', line 815

def create_copy_ref(path)
    path = "/copy_ref/#{@root}#{format_path(path)}"

    response = @session.do_get(build_url(path, {}))

    parse_response(response)
end

#delta(cursor = nil) ⇒ Object

A way of letting you keep a local representation of the Dropbox folder heirarchy. You can periodically call delta() to get a list of “delta entries”, which are instructions on how to update your local state to match the server’s state.

Arguments:

  • cursor: On the first call, omit this argument (or pass in nil). On subsequent calls, pass in the cursor string returned by the previous call.

Returns: A hash with three fields.

  • entries: A list of “delta entries” (described below)

  • reset: If true, you should reset local state to be an empty folder before processing the list of delta entries. This is only true only in rare situations.

  • cursor: A string that is used to keep track of your current state. On the next call to delta(), pass in this value to return entries that were recorded since the cursor was returned.

  • has_more: If true, then there are more entries available; you can call delta() again immediately to retrieve those entries. If false, then wait at least 5 minutes (preferably longer) before checking again.

Delta Entries: Each entry is a 2-item list of one of following forms:

  • [path, metadata]: Indicates that there is a file/folder at the given path. You should add the entry to your local state. (The metadata value is the same as what would be returned by the #metadata() call.)

    • If the path refers to parent folders that don’t yet exist in your local state, create those parent folders in your local state. You will eventually get entries for those parent folders.

    • If the new entry is a file, replace whatever your local state has at path with the new entry.

    • If the new entry is a folder, check what your local state has at path. If it’s a file, replace it with the new entry. If it’s a folder, apply the new metadata to the folder, but do not modify the folder’s children.

  • [path, nil]: Indicates that there is no file/folder at the path on Dropbox. To update your local state to match, delete whatever is at path, including any children (you will sometimes also get separate delta entries for each child, but this is not guaranteed). If your local state doesn’t have anything at path, ignore this entry.

Remember: Dropbox treats file names in a case-insensitive but case-preserving way. To facilitate this, the path strings above are lower-cased versions of the actual path. The metadata dicts have the original, case-preserved path.



771
772
773
774
775
776
777
778
779
# File 'lib/dropbox_sdk.rb', line 771

def delta(cursor=nil)
    params = {}
    if cursor
        params['cursor'] = cursor
    end

    response = @session.do_post build_url("/delta", params)
    parse_response(response)
end

#file_copy(from_path, to_path) ⇒ Object

Copy a file or folder to a new location.

Arguments:

  • from_path: The path to the file or folder to be copied.

  • to_path: The destination path of the file or folder to be copied. This parameter should include the destination filename (e.g. from_path: ‘/test.txt’, to_path: ‘/dir/test.txt’). If there’s already a file at the to_path, this copy will be renamed to be unique.

Returns:



483
484
485
486
487
488
489
490
491
# File 'lib/dropbox_sdk.rb', line 483

def file_copy(from_path, to_path)
    params = {
        "root" => @root,
        "from_path" => format_path(from_path, false),
        "to_path" => format_path(to_path, false),
    }
    response = @session.do_post build_url("/fileops/copy", params)
    parse_response(response)
end

#file_create_folder(path) ⇒ Object

Create a folder.

Arguments:

  • path: The path of the new folder.

Returns:



502
503
504
505
506
507
508
509
510
# File 'lib/dropbox_sdk.rb', line 502

def file_create_folder(path)
    params = {
        "root" => @root,
        "path" => format_path(path, false),
    }
    response = @session.do_post build_url("/fileops/create_folder", params)

    parse_response(response)
end

#file_delete(path) ⇒ Object

Deletes a file

Arguments:

  • path: The path of the file to delete

Returns:



521
522
523
524
525
526
527
528
# File 'lib/dropbox_sdk.rb', line 521

def file_delete(path)
    params = {
        "root" => @root,
        "path" => format_path(path, false),
    }
    response = @session.do_post build_url("/fileops/delete", params)
    parse_response(response)
end

#file_move(from_path, to_path) ⇒ Object

Moves a file

Arguments:

  • from_path: The path of the file to be moved

  • to_path: The destination path of the file or folder to be moved If the file or folder already exists, it will be renamed to be unique.

Returns:



541
542
543
544
545
546
547
548
549
# File 'lib/dropbox_sdk.rb', line 541

def file_move(from_path, to_path)
    params = {
        "root" => @root,
        "from_path" => format_path(from_path, false),
        "to_path" => format_path(to_path, false),
    }
    response = @session.do_post build_url("/fileops/move", params)
    parse_response(response)
end

#format_path(path, escape = true) ⇒ Object

:nodoc:



869
870
871
872
873
874
875
876
877
878
879
880
881
# File 'lib/dropbox_sdk.rb', line 869

def format_path(path, escape=true) # :nodoc:
    path = path.gsub(/\/+/,"/")
    # replace multiple slashes with a single one

    path = path.gsub(/^\/?/,"/")
    # ensure the path starts with a slash

    path.gsub(/\/?$/,"")
    # ensure the path doesn't end with a slash

    return URI.escape(path, RESERVED_CHARACTERS) if escape
    path
end

#get_file(from_path, rev = nil) ⇒ Object

Download a file

Args:

  • from_path: The path to the file to be downloaded

  • rev: A previous revision value of the file to be downloaded

Returns:

  • The file contents.



412
413
414
415
# File 'lib/dropbox_sdk.rb', line 412

def get_file(from_path, rev=nil)
    response = get_file_impl(from_path, rev)
    parse_response(response, raw=true)
end

#get_file_and_metadata(from_path, rev = nil) ⇒ Object

Download a file and get its metadata.

Args:

  • from_path: The path to the file to be downloaded

  • rev: A previous revision value of the file to be downloaded

Returns:

  • The file contents.

  • The file metadata as a hash.



426
427
428
429
430
431
# File 'lib/dropbox_sdk.rb', line 426

def (from_path, rev=nil)
    response = get_file_impl(from_path, rev)
    parsed_response = parse_response(response, raw=true)
     = (response)
    return parsed_response, 
end

#media(path) ⇒ Object

Returns a direct link to a media file All of Dropbox’s API methods require OAuth, which may cause problems in situations where an application expects to be able to hit a URL multiple times (for example, a media player seeking around a video file). This method creates a time-limited URL that can be accessed without any authentication.

Arguments:

  • path: The file to stream.

Returns:

  • A Hash object that looks like the following:

    {'url': 'https://dl.dropbox.com/0/view/wvxv1fw6on24qw7/file.mov', 'expires': 'Thu, 16 Sep 2011 01:01:25 +0000'}
    


671
672
673
674
# File 'lib/dropbox_sdk.rb', line 671

def media(path)
    response = @session.do_get build_url("/media/#{@root}#{format_path(path)}")
    parse_response(response)
end

#metadata(path, file_limit = 10000, list = true, hash = nil, rev = nil, include_deleted = false) ⇒ Object

Retrives metadata for a file or folder

Arguments:

  • path: The path to the file or folder.

  • list: Whether to list all contained files (only applies when path refers to a folder).

  • file_limit: The maximum number of file entries to return within a folder. If the number of files in the directory exceeds this limit, an exception is raised. The server will return at max 10,000 files within a folder.

  • hash: Every directory listing has a hash parameter attached that can then be passed back into this function later to save on bandwidth. Rather than returning an unchanged folder’s contents, if the hash matches a DropboxNotModified exception is raised.

  • rev: Optional. The revision of the file to retrieve the metadata for. This parameter only applies for files. If omitted, you’ll receive the most recent revision metadata.

  • include_deleted: Specifies whether to include deleted files in metadata results.

Returns:



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/dropbox_sdk.rb', line 574

def (path, file_limit=10000, list=true, hash=nil, rev=nil, include_deleted=false)
    params = {
        "file_limit" => file_limit.to_s,
        "list" => list.to_s,
        "include_deleted" => include_deleted.to_s
    }

    params["hash"] = hash if hash
    params["rev"] = rev if rev

    response = @session.do_get build_url("/metadata/#{@root}#{format_path(path)}", params=params)
    if response.kind_of? Net::HTTPRedirection
            raise DropboxNotModified.new("metadata not modified")
    end
    parse_response(response)
end

#parse_response(response, raw = false) ⇒ Object

Parse response. You probably shouldn’t be calling this directly. This takes responses from the server and parses them. It also checks for errors and raises exceptions with the appropriate messages.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/dropbox_sdk.rb', line 318

def parse_response(response, raw=false) # :nodoc:
    if response.kind_of?(Net::HTTPServerError)
        raise DropboxError.new("Dropbox Server Error: #{response} - #{response.body}", response)
    elsif response.kind_of?(Net::HTTPUnauthorized)
        raise DropboxAuthError.new(response, "User is not authenticated.")
    elsif not response.kind_of?(Net::HTTPSuccess)
        begin
            d = JSON.parse(response.body)
        rescue
            raise DropboxError.new("Dropbox Server Error: body=#{response.body}", response)
        end
        if d['user_error'] and d['error']
            raise DropboxError.new(d['error'], response, d['user_error'])  #user_error is translated
        elsif d['error']
            raise DropboxError.new(d['error'], response)
        else
            raise DropboxError.new(response.body, response)
        end
    end

    return response.body if raw

    begin
        return JSON.parse(response.body)
    rescue JSON::ParserError
        raise DropboxError.new("Unable to parse JSON response: #{response.body}", response)
    end
end

#put_file(to_path, file_obj, overwrite = false, parent_rev = nil) ⇒ Object

Uploads a file to a server. This uses the HTTP PUT upload method for simplicity

Arguments:

  • to_path: The directory path to upload the file to. If the destination directory does not yet exist, it will be created.

  • file_obj: A file-like object to upload. If you would like, you can pass a string as file_obj.

  • overwrite: Whether to overwrite an existing file at the given path. [default is False] If overwrite is False and a file already exists there, Dropbox will rename the upload to make sure it doesn’t overwrite anything. You must check the returned metadata to know what this new name is. This field should only be True if your intent is to potentially clobber changes to a file that you don’t know about.

  • parent_rev: The rev field from the ‘parent’ of this upload. [optional] If your intent is to update the file at the given path, you should pass the parent_rev parameter set to the rev value from the most recent metadata you have of the existing file at that path. If the server has a more recent version of the file at the specified path, it will automatically rename your uploaded file, spinning off a conflict. Using this parameter effectively causes the overwrite parameter to be ignored. The file will always be overwritten if you send the most-recent parent_rev, and it will never be overwritten you send a less-recent one.

Returns:

  • a Hash containing the metadata of the newly uploaded file. The file may have a different name if it conflicted.

Simple Example

client = DropboxClient(session, :app_folder)
#session is a DropboxSession I've already authorized
client.put_file('/test_file_on_dropbox', open('/tmp/test_file'))

This will upload the “/tmp/test_file” from my computer into the root of my App’s app folder and call it “test_file_on_dropbox”. The file will not overwrite any pre-existing file.



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/dropbox_sdk.rb', line 388

def put_file(to_path, file_obj, overwrite=false, parent_rev=nil)
    path = "/files_put/#{@root}#{format_path(to_path)}"

    params = {
        'overwrite' => overwrite.to_s
    }

    params['parent_rev'] = parent_rev unless parent_rev.nil?

    response = @session.do_put(build_url(path, params, content_server=true),
                               {"Content-Type" => "application/octet-stream"},
                               file_obj)

    parse_response(response)
end

#restore(path, rev) ⇒ Object

Restore a file to a previous revision.

Arguments:

  • path: The file to restore. Note that folders can’t be restored.

  • rev: A previous rev value of the file to be restored to.

Returns:



650
651
652
653
654
655
656
657
# File 'lib/dropbox_sdk.rb', line 650

def restore(path, rev)
    params = {
        'rev' => rev.to_s
    }

    response = @session.do_post build_url("/restore/#{@root}#{format_path(path)}", params)
    parse_response(response)
end

#revisions(path, rev_limit = 1000) ⇒ Object

Retrive revisions of a file

Arguments:

  • path: The file to fetch revisions for. Note that revisions are not available for folders.

  • rev_limit: The maximum number of file entries to return within a folder. The server will return at max 1,000 revisions.

Returns:



629
630
631
632
633
634
635
636
637
638
# File 'lib/dropbox_sdk.rb', line 629

def revisions(path, rev_limit=1000)

    params = {
        'rev_limit' => rev_limit.to_s
    }

    response = @session.do_get build_url("/revisions/#{@root}#{format_path(path)}", params)
    parse_response(response)

end

#search(path, query, file_limit = 1000, include_deleted = false) ⇒ Object

Search directory for filenames matching query

Arguments:

  • path: The directory to search within

  • query: The query to search on (3 character minimum)

  • file_limit: The maximum number of file entries to return/ If the number of files exceeds this limit, an exception is raised. The server will return at max 1,000

  • include_deleted: Whether to include deleted files in search results

Returns:



605
606
607
608
609
610
611
612
613
614
# File 'lib/dropbox_sdk.rb', line 605

def search(path, query, file_limit=1000, include_deleted=false)
    params = {
        'query' => query,
        'file_limit' => file_limit.to_s,
        'include_deleted' => include_deleted.to_s
    }

    response = @session.do_get build_url("/search/#{@root}#{format_path(path)}", params)
    parse_response(response)
end

#shares(path) ⇒ Object

Get a URL to share a media file Shareable links created on Dropbox are time-limited, but don’t require any authentication, so they can be given out freely. The time limit should allow at least a day of shareability, though users have the ability to disable a link from their account if they like.

Arguments:

  • path: The file to share.

Returns:

  • A Hash object that looks like the following example:

    {'url': 'http://www.dropbox.com/s/m/a2mbDa2', 'expires': 'Thu, 16 Sep 2011 01:01:25 +0000'}
    

    For a detailed description of what this call returns, visit:

    https://www.dropbox.com/developers/reference/api#shares
    


690
691
692
693
# File 'lib/dropbox_sdk.rb', line 690

def shares(path)
    response = @session.do_get build_url("/shares/#{@root}#{format_path(path)}")
    parse_response(response)
end

#thumbnail(from_path, size = 'large') ⇒ Object

Download a thumbnail for an image.

Arguments:

  • from_path: The path to the file to be thumbnailed.

  • size: A string describing the desired thumbnail size. At this time, ‘small’, ‘medium’, and ‘large’ are officially supported sizes (32x32, 64x64, and 128x128 respectively), though others may be available. Check www.dropbox.com/developers/reference/api#thumbnails for more details. [defaults to large]

Returns:

  • The thumbnail data



706
707
708
709
# File 'lib/dropbox_sdk.rb', line 706

def thumbnail(from_path, size='large')
    response = thumbnail_impl(from_path, size)
    parse_response(response, raw=true)
end

#thumbnail_and_metadata(from_path, size = 'large') ⇒ Object

Download a thumbnail for an image alongwith the image’s metadata.

Arguments:

  • from_path: The path to the file to be thumbnailed.

  • size: A string describing the desired thumbnail size. See thumbnail() for details.

Returns:

  • The thumbnail data

  • The metadata for the image as a hash



720
721
722
723
724
725
# File 'lib/dropbox_sdk.rb', line 720

def (from_path, size='large')
    response = thumbnail_impl(from_path, size)
    parsed_response = parse_response(response, raw=true)
     = (response)
    return parsed_response, 
end